@@ -178,7 +178,7 @@ peas_gtk_disable_plugins_dialog_init (PeasGtkDisablePluginsDialog *dialog)
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
   gtk_dialog_add_button (GTK_DIALOG (dialog),
-                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+                         _("_Cancel"), GTK_RESPONSE_CANCEL);
   gtk_dialog_add_button (GTK_DIALOG (dialog),
                          _("Disable Plugins"), GTK_RESPONSE_OK);
 }
