@@ -25,12 +25,14 @@
 
 #include "peas-plugin-loader.h"
 
-G_DEFINE_ABSTRACT_TYPE (PeasPluginLoader, peas_plugin_loader, G_TYPE_OBJECT);
+G_DEFINE_ABSTRACT_TYPE (PeasPluginLoader, peas_plugin_loader, G_TYPE_OBJECT)
 
 static void
 peas_plugin_loader_finalize (GObject *object)
 {
   g_debug ("Plugin Loader '%s' Finalized", G_OBJECT_TYPE_NAME (object));
+
+  G_OBJECT_CLASS (peas_plugin_loader_parent_class)->finalize (object);
 }
 
 static void
