@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __TESTING_H__
@@ -27,7 +27,8 @@
 
 G_BEGIN_DECLS
 
-void        testing_init        (void);
+void        testing_init        (gint    *argc,
+                                 gchar ***argv);
 
 PeasEngine *testing_engine_new  (void);
 
